@@ -1,18 +1,15 @@
 #!/usr/bin/env python
 import os
 import re
-import socketserver
 import subprocess
-import sys
 import json
-from http.server import SimpleHTTPRequestHandler
 
 import click
 from click.exceptions import ClickException
 from cookiecutter.main import cookiecutter
 
-from . import __version__
-from .auth import (
+from arcl import __version__
+from arcl.auth import (
     AUTH_ACTIONS,
     AUTH_ACTIONS_GET_TOKEN,
     AUTH_ACTIONS_LOGIN,
@@ -21,12 +18,13 @@ from .auth import (
     ArchimedesAuth,
     get_accepted_env,
 )
-from .config import get_config_path
+from arcl.config import get_config_path
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 COOKIECUTTER_TEMPLATE_GIT_URL = (
     "https://github.com/OptimeeringAS/archimedes-cookiecutter.git"
 )
+DEFAULT_AUTHOR_NAME = "Optimeering AS <dev@optimeering.com>"
 
 # source for official regex for semver:
 # https://semver.org/#is-there-a-suggested-regular-expression-regex-to-check-a-semver-string
@@ -86,15 +84,15 @@ def _get_version_from_python_version_string(version_string):
 
 def get_config(project_name, env):
     """Create a config for the project"""
-    if not os.path.exists(get_config_path(env)):
-        raise ConfigNotFoundException(
-            "User not logged in. Please log in using `arcl auth login <organization_id>`."
-        )
+    author_name = DEFAULT_AUTHOR_NAME
+
+    if os.path.exists(get_config_path(env)):
+        config = json.loads(open(get_config_path(env), "r").read())
+        author_name = get_author_name(config["user"])
 
-    config = json.loads(open(get_config_path(env), "r").read())
     return {
         "project_name": project_name,
-        "author_name": get_author_name(config["user"]),
+        "author_name": author_name,
         "python_version": get_python_version(),
     }
 
@@ -107,10 +105,8 @@ def cli():
     \b
     Commands:
         arcl new         Create a new project
-        arcl docs        Show the docs
         arcl auth        Handle Archimedes authentication
         arcl version     Print the version number
-        arcl config      Print the current configuration
     """
     pass
 
@@ -149,19 +145,8 @@ def auth(action, organization, env):
         click.echo(archimedes_auth.show())
 
 
-# remove the examples flag
-# create /production/sample.py instead from the other repo
-# deploy basic version of price/load prediction
-# does adding more PriceAreas increase the precision?
 @cli.command(hidden=True)
 @click.argument("name", required=True)
-@click.argument("env", required=False)
-# @click.option(
-#     "--examples",
-#     is_flag=True,
-#     help="Add this flag to include example files",
-# )
-# def new(name, examples):
 @click.option(
     "--template-version",
     "-t",
@@ -170,29 +155,20 @@ def auth(action, organization, env):
     f"{COOKIECUTTER_TEMPLATE_GIT_URL}",
     default=None,
 )
-def new(name, template_version, env="prod"):
+def new(name, template_version):
     """"""
-    # if examples == True:
-    #     examples_ = "yes"
-    # else:
-    #     examples_ = "no"
-
     try:
         project_dir = cookiecutter(
             COOKIECUTTER_TEMPLATE_GIT_URL,
             checkout=template_version,
-            extra_context=get_config(name, env),
+            extra_context=get_config(name, "prod"),
             no_input=True,
         )
     except ConfigNotFoundException as e:
         click.echo(e)
         return
 
-    # if examples:
-    if False:
-        click.echo(f"\nYour new project (and example files) has been created!")
-    else:
-        click.echo(f"\nYour new project has been created!")
+    click.echo(f"\nYour new project has been created!")
     click.echo("")
     click.echo(f'$ cd "{project_dir}"')
     click.echo(f"$ python -m pip install wheel pip --upgrade")
@@ -211,29 +187,5 @@ def version():
     click.echo(__version__)
 
 
-# Docs request handler, serving path ./docs
-class Handler(SimpleHTTPRequestHandler):
-    def __init__(self, *args, **kwargs):
-        docs_path = os.path.abspath((os.path.join(os.path.dirname(__file__), "docs")))
-        super().__init__(*args, directory=docs_path, **kwargs)
-
-
-@cli.command(hidden=True)
-def docs():
-    """
-    Start local documentation server
-    """
-    try:
-        httpd = socketserver.TCPServer(("", 0), Handler)
-        port = httpd.server_address[1]
-        print(f"Serving docs at: http://localhost:{port}")
-        httpd.serve_forever()
-    except KeyboardInterrupt:
-        httpd.shutdown()
-        httpd.server_close()
-        print(f"Shutdown server: http://localhost:{port}")
-        sys.exit(0)
-
-
 if __name__ == "__main__":
     cli()
